@@ -1,11 +1,12 @@
 from nonebot import on_message
-from nonebot.adapters.onebot.v11 import Bot
+from nonebot.adapters.onebot.v11 import Bot, GroupMessageEvent
 from nonebot import get_driver
+from nonebot_plugin_guild_patch import GuildMessageEvent
 
-from .data_source import *
-from src.mc_qq_config import ws_url, group_list
+from .data_source import send_msg_to_mc, on_connect
+from src.mc_qq_config import group_list
 
-msg_qq = on_message(priority=5)
+mc_qq = on_message(priority=5)
 driver = get_driver()
 
 
@@ -14,13 +15,13 @@ driver = get_driver()
 async def on_open(bot: Bot):
     # 循环尝试连接
     while True:
-        await on_connect(ws_url, bot=bot)
+        await on_connect(bot=bot)
         if not OSError:
             break
 
 
 # 收到 群/频 道消息时
-@msg_qq.handle()
+@mc_qq.handle()
 async def handle_first_receive(event: GroupMessageEvent | GuildMessageEvent, bot: Bot):
     if isinstance(event, GroupMessageEvent):
         if event.group_id in group_list['group_list']:
